<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AudioContainerControl</name>
    <message>
        <source>RAW (headerless) file format</source>
        <translation>RAW-tiedostomuoto (tunnukseton)</translation>
    </message>
    <message>
        <source>WAV file format</source>
        <translation>WAV-tiedostomuoto</translation>
    </message>
</context>
<context>
    <name>AudioEncoderControl</name>
    <message>
        <source>Linear PCM audio data</source>
        <translation>Lineaarinen PCM-äänidata</translation>
    </message>
</context>
<context>
    <name>BbCameraAudioEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Ei pakkausta</translation>
    </message>
    <message>
        <source>AAC compression</source>
        <translation>AAC-pakkaus</translation>
    </message>
    <message>
        <source>PCM uncompressed</source>
        <translation>PCM, pakkaamaton</translation>
    </message>
</context>
<context>
    <name>BbCameraMediaRecorderControl</name>
    <message>
        <source>Unable to retrieve mute status</source>
        <translation>Ei voitu hakea vaimennuksen tilaa</translation>
    </message>
    <message>
        <source>Unable to retrieve audio input volume</source>
        <translation>Ei voitu hakea äänitulon voimakkuutta</translation>
    </message>
    <message>
        <source>Unable to set mute status</source>
        <translation>Ei voitu asettaa vaimennuksen tilaa</translation>
    </message>
    <message>
        <source>Unable to set audio input volume</source>
        <translation>Ei voitu asettaa äänitulon voimakkuutta</translation>
    </message>
</context>
<context>
    <name>BbCameraSession</name>
    <message>
        <source>Camera provides image in unsupported format</source>
        <translation>Kameralta saatu kuva ei ole tuetussa muodossa</translation>
    </message>
    <message>
        <source>Could not load JPEG data from frame</source>
        <translation>JPEG-dataa ei saatu ladattua puskurista</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera ei ole valmis</translation>
    </message>
    <message>
        <source>Unable to apply video settings</source>
        <translation>Videoasetusten asettaminen epäonnistui</translation>
    </message>
    <message>
        <source>Could not open destination file:
%1</source>
        <translation>Virhe avattaessa kohdetiedostoa:
%1</translation>
    </message>
    <message>
        <source>Unable to open camera</source>
        <translation>Ei voitu avata kameraa</translation>
    </message>
    <message>
        <source>Unable to retrieve native camera orientation</source>
        <translation>Ei voitu hakea kameran asennusasentoa</translation>
    </message>
    <message>
        <source>Unable to close camera</source>
        <translation>Ei voitu sulkea kameraa</translation>
    </message>
    <message>
        <source>Unable to start video recording</source>
        <translation>Ei voitu aloittaa videon tallennusta</translation>
    </message>
    <message>
        <source>Unable to stop video recording</source>
        <translation>Ei voitu lopettaa videon tallennusta</translation>
    </message>
</context>
<context>
    <name>BbCameraVideoEncoderSettingsControl</name>
    <message>
        <source>No compression</source>
        <translation>Ei pakkausta</translation>
    </message>
    <message>
        <source>AVC1 compression</source>
        <translation>AVC1-pakkaus</translation>
    </message>
    <message>
        <source>H264 compression</source>
        <translation>H264-pakkaus</translation>
    </message>
</context>
<context>
    <name>BbImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-kuva</translation>
    </message>
</context>
<context>
    <name>BbVideoDeviceSelectorControl</name>
    <message>
        <source>Front Camera</source>
        <translation>Etukamera</translation>
    </message>
    <message>
        <source>Rear Camera</source>
        <translation>Takakamera</translation>
    </message>
    <message>
        <source>Desktop Camera</source>
        <translation>Työpöytäkamera</translation>
    </message>
</context>
<context>
    <name>CameraBinImageCapture</name>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera ei ole valmis</translation>
    </message>
</context>
<context>
    <name>CameraBinImageEncoder</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-kuva</translation>
    </message>
</context>
<context>
    <name>CameraBinRecorder</name>
    <message>
        <source>QMediaRecorder::pause() is not supported by camerabin2.</source>
        <translation>camerabin2 ei tue QMediaRecorder::pause()-funktiota.</translation>
    </message>
    <message>
        <source>Service has not been started</source>
        <translation>Palvelua ei ole käynnistetty</translation>
    </message>
    <message>
        <source>Recording permissions are not available</source>
        <translation>Tallennusoikeutta ei ole</translation>
    </message>
</context>
<context>
    <name>CameraBinSession</name>
    <message>
        <source>Camera error</source>
        <translation>Kameravirhe</translation>
    </message>
</context>
<context>
    <name>DSCameraSession</name>
    <message>
        <source>Camera not ready for capture</source>
        <translation>Kamera ei ole valmiina kaappaamaan</translation>
    </message>
    <message>
        <source>Could not save image to file.</source>
        <translation>Kuvan tallentaminen tiedostoon epäonnistui.</translation>
    </message>
</context>
<context>
    <name>MFPlayerSession</name>
    <message>
        <source>Invalid stream source.</source>
        <translation>Virheellinen virran lähde.</translation>
    </message>
    <message>
        <source>Attempting to play invalid Qt resource.</source>
        <translation>Yritettiin toistaa virheellinen Qt-resurssi.</translation>
    </message>
    <message>
        <source>The system cannot find the file specified.</source>
        <translation>Järjestelmä ei löydä määritettyä tiedostoa.</translation>
    </message>
    <message>
        <source>The specified server could not be found.</source>
        <translation>Määritettyä palvelinta ei löydy.</translation>
    </message>
    <message>
        <source>Unsupported media type.</source>
        <translation>Mediatyyppiä ei tueta.</translation>
    </message>
    <message>
        <source>Failed to load source.</source>
        <translation>Virhe ladattaessa lähdettä.</translation>
    </message>
    <message>
        <source>Cannot create presentation descriptor.</source>
        <translation>Ei voitu luoda esityksen kuvausta.</translation>
    </message>
    <message>
        <source>Failed to get stream count.</source>
        <translation>Virtojen määrän hakeminen epäonnistui.</translation>
    </message>
    <message>
        <source>Failed to create topology.</source>
        <translation>Topologian luonti epäonnistui.</translation>
    </message>
    <message>
        <source>Unable to play any stream.</source>
        <translation>Ei voitu toistaa yhtään virtaa.</translation>
    </message>
    <message>
        <source>Unable to play.</source>
        <translation>Ei voitu toistaa.</translation>
    </message>
    <message>
        <source>Failed to set topology.</source>
        <translation>Topologian asettaminen epäonnistui.</translation>
    </message>
    <message>
        <source>Unknown stream type.</source>
        <translation>Tuntematon virtatyyppi.</translation>
    </message>
    <message>
        <source>Failed to stop.</source>
        <translation>Pysäyttäminen epäonnistui.</translation>
    </message>
    <message>
        <source>failed to start playback</source>
        <translation>toiston aloittaminen epäonnistui</translation>
    </message>
    <message>
        <source>Failed to pause.</source>
        <translation>Tauon aloittaminen epäonnistui.</translation>
    </message>
    <message>
        <source>Unable to create mediasession.</source>
        <translation>Ei voitu luoda mediaistuntoa.</translation>
    </message>
    <message>
        <source>Unable to pull session events.</source>
        <translation>Ei voitu hakea istunnon tapahtumia.</translation>
    </message>
    <message>
        <source>Failed to seek.</source>
        <translation>Sijainnin asettaminen epäonnistui.</translation>
    </message>
    <message>
        <source>Media session non-fatal error.</source>
        <translation>Ei vakava virhe mediaistunnossa.</translation>
    </message>
    <message>
        <source>Media session serious error.</source>
        <translation>Vakava virhe mediaistunnossa.</translation>
    </message>
    <message>
        <source>Unsupported media, a codec is missing.</source>
        <translatorcomment>Pakkauksenhallinta on Microsoftin käyttämä suomennos sanalle codec. Koska tämä teksti on käytössä vain Windowsissa, niin paras kaiketi käyttää sitä.</translatorcomment>
        <translation>Mediaa ei tueta, pakkauksenhallinta puuttuu.</translation>
    </message>
</context>
<context>
    <name>QAndroidAudioEncoderSettingsControl</name>
    <message>
        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
        <translation>Adaptive Multi-Rate Narrowband (AMR-NB) äänikoodekki</translation>
    </message>
    <message>
        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
        <translation>Adaptive Multi-Rate Wideband (AMR-WB) äänikoodekki</translation>
    </message>
    <message>
        <source>AAC Low Complexity (AAC-LC) audio codec</source>
        <translation>AAC Low Complexity (AAC-LC) äänikoodekki</translation>
    </message>
</context>
<context>
    <name>QAndroidCameraSession</name>
    <message>
        <source>Camera cannot be started without a viewfinder.</source>
        <translation>Kameraa ei voida käynnistää ilman etsintä.</translation>
    </message>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera ei ole valmis</translation>
    </message>
    <message>
        <source>Drive mode not supported</source>
        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
        <translation>Kuvaustilaa ei tueta</translation>
    </message>
    <message>
        <source>Failed to capture image</source>
        <translation>Kuvan ottaminen epäonnistui</translation>
    </message>
    <message>
        <source>Camera preview failed to start.</source>
        <translation>Kameran esikatselun käynnistys epäonnistui.</translation>
    </message>
    <message>
        <source>Could not open destination file: %1</source>
        <translation>Kohdetiedostoa ei voitu avata: %1</translation>
    </message>
</context>
<context>
    <name>QAndroidImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-kuva</translation>
    </message>
</context>
<context>
    <name>QAndroidMediaContainerControl</name>
    <message>
        <source>MPEG4 media file format</source>
        <translation>MPEG4-tiedostomuoto</translation>
    </message>
    <message>
        <source>3GPP media file format</source>
        <translation>3GPP-tiedostomuoto</translation>
    </message>
    <message>
        <source>AMR NB file format</source>
        <translation>AMR NB -tiedostomuoto</translation>
    </message>
    <message>
        <source>AMR WB file format</source>
        <translation>AMR WB -tiedostomuoto</translation>
    </message>
</context>
<context>
    <name>QAndroidVideoEncoderSettingsControl</name>
    <message>
        <source>H.263 compression</source>
        <translation>H.263-pakkaus</translation>
    </message>
    <message>
        <source>H.264 compression</source>
        <translation>H.264-pakkaus</translation>
    </message>
    <message>
        <source>MPEG-4 SP compression</source>
        <translation>MPEG-4 SP -pakkaus</translation>
    </message>
</context>
<context>
    <name>QAudioDecoder</name>
    <message>
        <source>The QAudioDecoder object does not have a valid service</source>
        <translation>QAudioDecoder-oliolla ei ole sopivaa palvelua</translation>
    </message>
</context>
<context>
    <name>QCamera</name>
    <message>
        <source>The camera service is missing</source>
        <translation>Ei kamerapalvelua</translation>
    </message>
</context>
<context>
    <name>QCameraImageCapture</name>
    <message>
        <source>Device does not support images capture.</source>
        <translation>Laite ei tue kuvien ottamista.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeAudio</name>
    <message>
        <source>volume should be between 0.0 and 1.0</source>
        <translatorcomment>volume viittaa metodin parametrin nimeen</translatorcomment>
        <translation>volume-parametrin arvo pitää olla 0,0 ja 1,0 välillä</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioDecoderSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Ei voida toistaa virtaa jonka tyyppi on: &lt;tuntematon&gt;</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioEncode</name>
    <message>
        <source>Raw PCM audio</source>
        <translation>Raaka PCM-audio</translation>
    </message>
</context>
<context>
    <name>QGstreamerAudioInputSelector</name>
    <message>
        <source>System default device</source>
        <translation>Järjestelmän oletuslaite</translation>
    </message>
</context>
<context>
    <name>QGstreamerCameraControl</name>
    <message>
        <source>State not supported.</source>
        <translation>Tila ei ole tuettu.</translation>
    </message>
</context>
<context>
    <name>QGstreamerCaptureSession</name>
    <message>
        <source>Could not create an audio source element</source>
        <translation>Ei voitu luoda äänilähde-elementtiä</translation>
    </message>
    <message>
        <source>Failed to build media capture pipeline.</source>
        <translation>Virhe luotaessa median tallennusliukuhihnaa.</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageCaptureControl</name>
    <message>
        <source>Not ready to capture</source>
        <translation>Ei valmiina kaappaamaan</translation>
    </message>
</context>
<context>
    <name>QGstreamerImageEncode</name>
    <message>
        <source>JPEG image encoder</source>
        <translation>JPEG-kuvapakkaaja</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerControl</name>
    <message>
        <source>Attempting to play invalid user stream</source>
        <translation>Yritettiin toistaa virheellinen käyttäjän virta</translation>
    </message>
</context>
<context>
    <name>QGstreamerPlayerSession</name>
    <message>
        <source>Cannot play stream of type: &lt;unknown&gt;</source>
        <translation>Ei voida toistaa virtaa jonka tyyppi on: &lt;tuntematon&gt;</translation>
    </message>
    <message>
        <source>UDP source timeout</source>
        <translation>UDP-lähteen aikakatkaisu</translation>
    </message>
    <message>
        <source>Media is loaded as a playlist</source>
        <translation>Media on ladattu soittolistana</translation>
    </message>
</context>
<context>
    <name>QGstreamerRecorderControl</name>
    <message>
        <source>Service has not been started</source>
        <translation>Palvelua ei ole käynnistetty</translation>
    </message>
    <message>
        <source>Not compatible codecs and container format.</source>
        <translation>Yhteensopimattomat koodekit ja säiliömuoto.</translation>
    </message>
</context>
<context>
    <name>QGstreamerVideoInputDeviceControl</name>
    <message>
        <source>Main camera</source>
        <translation>Pääkamera</translation>
    </message>
    <message>
        <source>Front camera</source>
        <translation>Etukamera</translation>
    </message>
</context>
<context>
    <name>QMediaPlayer</name>
    <message>
        <source>Attempting to play invalid Qt resource</source>
        <translation>Yritetään toistaa virheellinen Qt-resurssi</translation>
    </message>
    <message>
        <source>The QMediaPlayer object does not have a valid service</source>
        <translation>QMediaPlayer-oliolla ei ole sopivaa palvelua</translation>
    </message>
</context>
<context>
    <name>QMediaPlaylist</name>
    <message>
        <source>Could not add items to read only playlist.</source>
        <translation>Ei voitu lisätä tietueita vain luettavaan soittolistaan.</translation>
    </message>
    <message>
        <source>Playlist format is not supported</source>
        <translation>Soittolistan muotoa ei tueta</translation>
    </message>
    <message>
        <source>The file could not be accessed.</source>
        <translation>Tiedostoa ei voitu käsitellä.</translation>
    </message>
    <message>
        <source>Playlist format is not supported.</source>
        <translation>Soittolistan muotoa ei tueta.</translation>
    </message>
</context>
<context>
    <name>QMultimediaDeclarativeModule</name>
    <message>
        <source>CameraCapture is provided by Camera</source>
        <translation>Camera tarjoaa CameraCapturen</translation>
    </message>
    <message>
        <source>CameraRecorder is provided by Camera</source>
        <translation>Camera tarjoaa CameraRecorderin</translation>
    </message>
    <message>
        <source>CameraExposure is provided by Camera</source>
        <translation>Camera tarjoaa CameraExposuren</translation>
    </message>
    <message>
        <source>CameraFocus is provided by Camera</source>
        <translation>Camera tarjoaa CameraFocusin</translation>
    </message>
    <message>
        <source>CameraFlash is provided by Camera</source>
        <translation>Camera tarjoaa CameraFlashin</translation>
    </message>
    <message>
        <source>CameraImageProcessing is provided by Camera</source>
        <translation>Camera tarjoaa CameraImageProcessingin</translation>
    </message>
    <message>
        <source>CameraViewfinder is provided by Camera</source>
        <translation>Camera tarjoaa CameraViewfinderin</translation>
    </message>
</context>
<context>
    <name>QPlaylistFileParser</name>
    <message>
        <source>%1 playlist type is unknown</source>
        <translation>soittolistan %1 tyyppi on tuntematon</translation>
    </message>
    <message>
        <source>invalid line in playlist file</source>
        <translation>virheellinen rivi soittolistatiedostossa</translation>
    </message>
    <message>
        <source>Empty file provided</source>
        <translation>Saatiin tyhjä tiedosto</translation>
    </message>
    <message>
        <source>%1 does not exist</source>
        <translation>%1 ei ole olemassa</translation>
    </message>
</context>
<context>
    <name>QWinRTCameraImageCaptureControl</name>
    <message>
        <source>Camera not ready</source>
        <translation>Kamera ei ole valmis</translation>
    </message>
    <message>
        <source>Invalid photo data length.</source>
        <translation>Virheellinen kuvadatan pituus.</translation>
    </message>
    <message>
        <source>Image saving failed</source>
        <translation>Kuvan tallentaminen epäonnistui</translation>
    </message>
</context>
<context>
    <name>QWinRTImageEncoderControl</name>
    <message>
        <source>JPEG image</source>
        <translation>JPEG-kuva</translation>
    </message>
</context>
</TS>
